using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.CompositeUI.SmartParts;
using System.Windows.Forms;
using System.Drawing;
using Microsoft.Practices.CompositeUI.Utility;

namespace Jbe.CABExtension.SmartPartInfos
{
    public class FormSmartPartInfo : IconSmartPartInfo
    {
        private Point location;
        private int height;
        private int width;
        private bool controlBox = true;
        private bool minimizeBox = true;
        private bool maximizeBox = true;
        private bool showIcon = true;
        private bool showInTaskBar = true;
        private bool showModal = false;
        private IButtonControl acceptButton;
        private IButtonControl cancelButton;

        public Point Location
        {
            get { return location; }
            set { location = value; }
        }

        public int Height
        {
            get { return height; }
            set { height = value; }
        }

        public int Width
        {
            get { return width; }
            set { width = value; }
        }

        public bool ControlBox
        {
            get { return controlBox; }
            set { controlBox = value; }
        }

        public bool MinimizeBox
        {
            get { return minimizeBox; }
            set { minimizeBox = value; }
        }
        
        public bool MaximizeBox
        {
            get { return maximizeBox; }
            set { maximizeBox = value; }
        }
        
        public bool ShowIcon
        {
            get { return showIcon; }
            set { showIcon = value; }
        }
        
        public bool ShowInTaskBar
        {
            get { return showInTaskBar; }
            set { showInTaskBar = value; }
        }

        public bool ShowModal
        {
            get { return showModal; }
            set { showModal = value; }
        }

        public IButtonControl AcceptButton
        {
            get { return acceptButton; }
            set { acceptButton = value; }
        }

        public IButtonControl CancelButton
        {
            get { return cancelButton; }
            set { cancelButton = value; }
        }

        public FormSmartPartInfo() : base(null, null) { }

        public FormSmartPartInfo(string title, string description) : base(title, description) { }

        /// <summary>
        /// Creates a new instance of the FormSmartPartInfo with the settings for a modal dialog
        /// </summary>
        public static FormSmartPartInfo CreateModalDialog()
        {
            return CreateModalDialog(string.Empty, string.Empty);
        }

        /// <summary>
        /// Creates a new instance of the FormSmartPartInfo with the settings for a modal dialog
        /// </summary>
        public static FormSmartPartInfo CreateModalDialog(string title, string description)
        {
            FormSmartPartInfo spi = new FormSmartPartInfo(title, description);
            spi.MinimizeBox = false;
            spi.MaximizeBox = false;
            spi.ShowIcon = false;
            spi.ShowInTaskBar = false;
            spi.ShowModal = true;
            return spi;
        }

        /// <summary>
        /// Creates a new instance of the FormSmartPartInfo and copies over the information 
        /// in the source smart part.
        /// </summary>
        public static FormSmartPartInfo ConvertTo(ISmartPartInfo source)
        {
            Guard.ArgumentNotNull(source, "source");

            FormSmartPartInfo info = new FormSmartPartInfo(source.Title, source.Description);

            IconSmartPartInfo iconInfo = source as IconSmartPartInfo;
            if (iconInfo != null) { info.Icon = iconInfo.Icon; }

            return info;
        }
    }
}
