using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using Microsoft.Practices.ObjectBuilder;
using Microsoft.Practices.CompositeUI.SmartParts;
using Jbe.CABExtension.WinForms;
using Jbe.TestSuite.Infrastructure.Interface.Constants;
using WeifenLuo.WinFormsUI.Docking;
using Jbe.TestSuite.Infrastructure.Layout.UIElements;
using Microsoft.Practices.CompositeUI.Commands;
using Jbe.CABExtension.WPF.Workspaces;
using Jbe.CABExtension.WinForms.UIElements;
using Microsoft.Practices.CompositeUI.WinForms.UIElements;

namespace Jbe.TestSuite.Infrastructure.Layout
{
    [SmartPart]
    public partial class ShellLayoutView : UserControl
    {
        private ShellLayoutViewPresenter presenter;
        private DockPanelWorkspace dockPanelWorkspace;

        [CreateNew]
        public ShellLayoutViewPresenter Presenter
        {
            set
            {
                presenter = value;
                presenter.View = this;

                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.MainMenu, mainMenuStrip);
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.MainStatus, mainStatusStrip);
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.MainToolbar, new AfterSeparatorUIAdapter(mainToolStripSeparator));
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.ToolBarPanel, toolStripContainer.TopToolStripPanel);
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.ViewMenuItem, new ToolStripDropDownItemUIAdapter(viewToolStripMenuItem, true));
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.HelpMenuItem, new InverseToolStripItemCollectionUIAdapter(helpToolStripMenuItem.DropDown.Items));
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.NewMenuItem, new ToolStripDropDownItemUIAdapter(newToolStripMenuItem));
                presenter.WorkItem.UIExtensionSites.RegisterSite(UIExtensionSiteNames.NewToolBarItem, new ToolStripDropDownItemUIAdapter(newToolStripDropDownButton));

                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Open, openToolStripMenuItem, openToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Save, saveToolStripMenuItem, saveToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.SaveAs, saveAsToolStripMenuItem);

                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Undo, undoToolStripMenuItem, undoToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Redo, redoToolStripMenuItem, redoToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Cut, cutToolStripMenuItem, cutToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Copy, copyToolStripMenuItem, copyToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Paste, pasteToolStripMenuItem, pasteToolStripButton);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.Delete, deleteToolStripMenuItem);
                CommandHelper.AddInvoker(presenter.WorkItem, CommandNames.SelectAll, selectAllToolStripMenuItem);
            }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="T:ShellLayoutView"/> class.
        /// </summary>
        public ShellLayoutView()
        {
            InitializeComponent();

            dockPanelWorkspace = new DockPanelWorkspace();
            dockPanelWorkspace.Name = WorkspaceNames.DockPanelWorkspace;
            dockPanelWorkspace.DocumentStyle = DocumentStyle.DockingWindow;
            dockPanelWorkspace.Dock = DockStyle.Fill;
            dockPanelWorkspace.DockTopPortion = 180;
            dockPanelWorkspace.DockBottomPortion = 180;
            dockPanelWorkspace.DockLeftPortion = 230;
            dockPanelWorkspace.DockRightPortion = 230;
            dockPanelWorkspace.ContentAdded += UpdateUI;
            dockPanelWorkspace.ContentRemoved += UpdateUI;
            dockPanelWorkspace.ActiveDocumentChanged += UpdateUI;
            dockPanelWorkspace.SmartPartActivated += DockPanelWorkspaceSmartPartActivated;

            newToolStripDropDownButton.Enabled = false;
            deleteToolStripMenuItem.ShortcutKeys = Keys.Delete;
            aboutToolStripMenuItem.Text += " " + Application.ProductName;

            toolStripContainer.ContentPanel.Controls.Add(dockPanelWorkspace);
        }

        public void SetStatusLabel(string text)
        {
            statusLabel.Text = text;
        }

        public bool CloseDocuments()
        {
            IDockContent[] documents = dockPanelWorkspace.GetDocuments();
            foreach (IDockContent content in documents)
            {
                content.DockHandler.Close();
            }

            return (dockPanelWorkspace.DocumentsCount == 0);
        }

        private void CloseToolStripMenuItemClick(object sender, EventArgs e)
        {
            dockPanelWorkspace.ActiveDocument.DockHandler.Close();
        }

        private void CloseAllToolStripMenuItemClick(object sender, EventArgs e)
        {
            CloseDocuments();
        }

        private void UpdateUI()
        {
            closeToolStripMenuItem.Enabled = (dockPanelWorkspace.ActiveDocument != null);
            closeAllToolStripMenuItem.Enabled = (dockPanelWorkspace.DocumentsCount > 0);
        }

        private void UpdateUI(object sender, EventArgs e)
        {
            UpdateUI();
        }

        private void FileExitClick(object sender, EventArgs e)
        {
            presenter.OnFileExit();
        }

        private void HelpAboutClick(object sender, EventArgs e)
        {
            presenter.ShowAbout();
        }

        private void DockPanelWorkspaceSmartPartActivated(object sender, WorkspaceEventArgs e)
        {
            // Workaround to activate the WorkItem (Only necessary for Windows Forms Controls)
            if (dockPanelWorkspace.ActiveSmartPart is Control)
            {
                ((Control)dockPanelWorkspace.ActiveSmartPart).Focus();
            }
        }
    }
}
