using System;
using System.Collections.Generic;
using System.Text;
using Jbe.TestSuite.Infrastructure.Interface.Services;
using System.Windows.Controls;
using System.Windows;

namespace Jbe.TestSuite.Infrastructure.Module.EditAdapters
{
    public class WPFTextBoxAdapter : IEditHandler
    {
        public event EventHandler Enter;
        public event EventHandler Leave;

        private TextBox adaptee;

        public virtual bool CanUndo
        {
            get { return adaptee.CanUndo; }
        }

        public virtual bool CanRedo
        {
            get { return adaptee.CanRedo; }
        }

        public virtual bool CanCut
        {
            get { return adaptee.SelectionLength > 0; }
        }

        public virtual bool CanCopy
        {
            get { return adaptee.SelectionLength > 0; }
        }

        public virtual bool CanPaste
        {
            get { return true; }
        }

        public virtual bool CanDelete
        {
            get { return adaptee.SelectionLength > 0; }
        }

        public virtual bool CanSelectAll
        {
            get { return adaptee.Text.Length > 0; }
        }

        public WPFTextBoxAdapter(TextBox adaptee)
        {
            this.adaptee = adaptee;
            RegisterEventDelegation();
        }

        public virtual void Undo()
        {
            adaptee.Undo();
        }

        public virtual void Redo()
        {
            adaptee.Redo();
        }

        public virtual void Cut()
        {
            adaptee.Cut();
        }

        public virtual void Copy()
        {
            adaptee.Copy();
        }

        public virtual void Paste()
        {
            adaptee.Paste();
        }

        public virtual void Delete()
        {
            adaptee.SelectedText = "";
        }

        public virtual void SelectAll()
        {
            adaptee.SelectAll();
        }

        protected virtual void OnEnter(EventArgs e) 
        {
            if (Enter != null) { Enter(this, e); }
        }

        protected virtual void OnLeave(EventArgs e)
        {
            if (Leave != null) { Leave(this, e); }
        }

        private void RegisterEventDelegation()
        {
            adaptee.GotFocus += new RoutedEventHandler(AdapteeEnter);
            adaptee.LostFocus += new RoutedEventHandler(AdapteeLeave);
        }

        private void AdapteeEnter(object sender, RoutedEventArgs e)
        {
            OnEnter(EventArgs.Empty);
        }
        
        private void AdapteeLeave(object sender, RoutedEventArgs e)
        {
            OnLeave(EventArgs.Empty);
        }
    }
}
