//----------------------------------------------------------------------------------------
// patterns & practices - Smart Client Software Factory - Guidance Package
//
// This file was generated by the "Add View" recipe.
//
// A presenter calls methods of a view to update the information that the view displays. 
// The view exposes its methods through an interface definition, and the presenter contains
// a reference to the view interface. This allows you to test the presenter with different 
// implementations of a view (for example, a mock view).
//
// For more information see:
// ms-help://MS.VSCC.v80/MS.VSIPCC.v80/ms.practices.scsf.2007may/SCSF/html/02-09-010-ModelViewPresenter_MVP.htm
//
// Latest version of this Guidance Package: http://go.microsoft.com/fwlink/?LinkId=62182
//----------------------------------------------------------------------------------------

using System;
using Microsoft.Practices.ObjectBuilder;
using Microsoft.Practices.CompositeUI;
using Jbe.TestSuite.Infrastructure.Interface;
using Jbe.TestSuite.Infrastructure.Interface.Services;
using Jbe.TestSuite.Message.Demo.Constants;
using Microsoft.Practices.CompositeUI.EventBroker;
using System.Diagnostics;
using System.Security.Authentication;

namespace Jbe.TestSuite.Message.Demo
{
    public partial class DemoViewPresenter : Presenter<IDemoView>
    {
        [EventPublication(EventTopicNames.StatusUpdate, PublicationScope.Global)]
        public event EventHandler<EventArgs<string>> StatusUpdate;

        public enum ExceptionType
        {
            Exception,
            AuthenticationException,
            EventTopicException
        }

        private IMessageService messageService;

        [ServiceDependency]
        public IMessageService MessageService
        {
            set { messageService = value; }
        }

        /// <summary>
        /// This method is a placeholder that will be called by the view when it has been loaded.
        /// </summary>
        public override void OnViewReady()
        {
            base.OnViewReady();
        }

        /// <summary>
        /// Close the view
        /// </summary>
        public void OnCloseView()
        {
            base.CloseView();
        }

        public void ShowInformationMessage(string message, string details)
        {
            messageService.ShowInformation(message, details);
        }

        public void ShowWarningMessage(string message, string details)
        {
            messageService.ShowWarning(message, details);
        }

        public void ShowErrorMessage(string message, string details)
        {
            messageService.ShowError(message, details);
        }

        public void ShowStatusBar(string message)
        {
            OnStatusUpdate(message);
        }

        public void ThrowException(ExceptionType exceptionType)
        {
            switch(exceptionType) {
                case ExceptionType.Exception:
                    throw new Exception();
                case ExceptionType.AuthenticationException:
                    throw new AuthenticationException();
                case ExceptionType.EventTopicException:
                    throw new EventTopicException();
                default:
                    Debug.Assert(false, "The default case is not allowed.");
                    break;
            }
        }

        protected virtual void OnStatusUpdate(string message)
        {
            if (StatusUpdate != null) { StatusUpdate(this, new EventArgs<string>(message)); }
        }
    }
}
